Module sequences

Module sequences 

How to handle color sequences for terminal emulators

Functions

set_color
private fn that returns sequences “Convert a hex color to a text color sequence”
set_special
Convert a hex color to a special sequence. Currently no alpha is supported. The sequence below is only supported by urxvt, by pywal
unix_term
Uses terminal sequences to update terminal colors ref: https://github.com/dylanaraps/pywal/blob/master/pywal/sequences.py